{ config, ... }:

{
  imports = [
    (builtins.fetchTarball {
      url = "https://gitlab.com/simple-nixos-mailserver/nixos-mailserver/-/archive/nixos-22.05/nixos-mailserver-nixos-22.05.tar.gz";
      sha256 = "0csx2i8p7gbis0n5aqpm57z5f9cd8n9yabq04bg1h4mkfcf7mpl6";
    })
  ];

  mailserver = {
    enable = true;
    fqdn = "mail.eurofusion.eu";
    domains = [ "eurofusion.eu" ];

    messageSizeLimit = 78643200;  # ~50MiB of base64 binary

    loginAccounts = config.secrets.emailAccounts;

    extraVirtualAliases = {
      "abuse@eurofusion.eu" = "rnhmjoj@eurofusion.eu";
    };

    # store state under /var
    mailDirectory    = "/var/lib/mail";
    dkimKeyDirectory = "/var/lib/dkim";

    mailboxes = {
      # default IMAP folders
      Sent   = { specialUse = "Sent";   auto = "subscribe"; };
      Drafts = { specialUse = "Drafts"; auto = "subscribe"; };
      Spam   = { specialUse = "Junk";   auto = "subscribe"; };
      Trash  = { specialUse = "Trash";  auto = "no"; };
    };

    # Use Let's Encrypt certificate
    certificateScheme = 3;

    # There is one already (pdns-recursor)
    localDnsResolver = false;

    # Enable IMAPS (993), SMTPS (465)
    enableImapSsl = true;
    enableImap = false;
    enableSubmissionSsl = true;
    enableSubmission = false;
  };

  services.dovecot2.extraConfig = ''
    # Improve hashing speed
    auth_cache_verify_password_with_worker = yes
  '';

  services.postfix.extraConfig = ''
    # Prefer IPv6
    smtp_address_preference = ipv6
    # Prevent binding on temporary addresses
    smtp_bind_address6 = 2001:470:c8e8:0:230:48ff:fefa:91e1
  '';

}
